#!/bin/sh

# SEQUOIA_HOME definition
if [ -z "$SEQUOIA_HOME" ] ; then 
  echo "Cannot find Sequoia home directory. Please set the SEQUOIA_HOME environment variable."
  exit 1
fi

# JAVA setup.
#
# We try to use first the java JVM in JAVA_HOME and if not found,
# we use the one found in the path.
# You can specify additional options to give to the Java JVM in the
# JVM_OPTIONS environment variable.
if [ -z "$JAVA_HOME" ]
then
    JAVA=`which java`
    if [ ! -x "$JAVA" ]; then
      echo "Cannot find java command. Please set the JAVA_HOME environment variable."
      exit 1
    fi
else
    JAVA=$JAVA_HOME/bin/java
fi
export JAVA

[ -z "$SEQUOIA_CONFIG" ] && SEQUOIA_CONFIG=$SEQUOIA_HOME/config
  
[ -z "$SEQUOIA_LOG" ] && SEQUOIA_LOG=$SEQUOIA_HOME/log
  
[ -z "$SEQUOIA_DEFAULT_JVMDEBUG_PORT" ] && SEQUOIA_DEFAULT_JVMDEBUG_PORT=51001
  

# swallow option not yet implemented
[ "$1" != "nobg" ] || shift

# IPv6 is untested
JVM_OPTIONS="-Djava.net.preferIPv4Stack=true ${JVM_OPTIONS}"

# Environment variables for OptimizeIt
# export LD_LIBRARY_PATH=/home/emmanuel/OptimizeitEntSuite60/lib/:$LD_LIBRARY_PATH
# export PATH=/home/emmanuel/OptimizeitEntSuite60/lib/:$PATH

# uncomment to debug
# JVM_OPTIONS="${JVM_OPTIONS} -enableassertions -Xdebug -Xnoagent -Djava.compiler=none -Xrunjdwp:transport=dt_socket,server=y,suspend=n,address=$SEQUOIA_DEFAULT_JVMDEBUG_PORT"
  
# Set the classpath.
unset CLASSPATH
CLASSPATH=:$SEQUOIA_HOME/lib/octopus/Octopus.jar:$SEQUOIA_HOME/lib/octopus/OctopusGenerator.jar:$SEQUOIA_HOME/lib/octopus/csvjdbc.jar:$SEQUOIA_HOME/lib/sequoia-controller.jar:$SEQUOIA_HOME/lib/sequoia-backend.jar:$SEQUOIA_HOME/lib/sequoia-backupers.jar:$SEQUOIA_HOME/lib/sequoia-cache.jar:$SEQUOIA_HOME/lib/sequoia-commons.jar:$SEQUOIA_HOME/lib/sequoia-jmx.jar:$SEQUOIA_HOME/lib/sequoia-sql.jar:$SEQUOIA_HOME/lib/octopus:$SEQUOIA_HOME/drivers:$SEQUOIA_HOME/lib/hedera-commons.jar:$SEQUOIA_HOME/lib/hedera-jgroups.jar:$SEQUOIA_HOME/lib/hedera-appia.jar:$SEQUOIA_HOME/lib/appia.jar:$SEQUOIA_HOME/lib/jgroups-core.jar:$SEQUOIA_HOME/lib/concurrent.jar:$SEQUOIA_HOME/lib/commons-logging.jar:$SEQUOIA_HOME/lib/dom4j-1.6.1.jar:$SEQUOIA_HOME/lib/jaxen-1.1-beta-8.jar:$SEQUOIA_HOME/lib/log4j.jar:$SEQUOIA_HOME/lib/activation.jar:$SEQUOIA_HOME/lib/mail.jar:$SEQUOIA_HOME/lib/commons-cli.jar:$SEQUOIA_HOME/lib/jmx/mx4j.jar:$SEQUOIA_HOME/lib/jmx/mx4j-remote.jar:$SEQUOIA_HOME/lib/jmx/mx4j-tools.jar:$SEQUOIA_HOME/xml:$SEQUOIA_HOME/lib/crimson.jar:$SEQUOIA_HOME/lib/xml-apis.jar:$SEQUOIA_CONFIG/controller:$SEQUOIA_CONFIG/virtualdatabase:$SEQUOIA_CONFIG/:$CLASSPATH_XTRA


# Change directory if needed


# Java Command.
$JAVA -classpath $CLASSPATH  -Dsequoia.home=$SEQUOIA_HOME  -Dsequoia.log=$SEQUOIA_LOG  -Djava.security.policy=$SEQUOIA_CONFIG/java.policy  $JVM_OPTIONS org.continuent.sequoia.controller.core.Controller  "$@"
